@@ -7,7 +7,7 @@
 ###
 ### This file is part of the `corpcor' library for R and related languages.
 ### It is made available under the terms of the GNU General Public
-### License, version 2, or at your option, any later version,
+### License, version 3, or at your option, any later version,
 ### incorporated herein by reference.
 ### 
 ### This program is distributed in the hope that it will be
@@ -23,9 +23,9 @@
 
 
 
-pseudoinverse <- function (m, tol)
+pseudoinverse = function (m, tol)
 {
-    msvd <- fast.svd(m, tol)
+    msvd = fast.svd(m, tol)
     
     if (length(msvd$d) == 0)
     {
